
From: Peter Osterlund <petero2@telia.com>

I found a bug in the packet writing driver that could cause data
corruption.  The problem arised if the driver got a write request for a
sector in a "zone" it was already working on.  In that case it was supposed
to queue the write request until it was done processing earlier requests
for the same zone, and instead work on some other zone in the mean time. 
However, if there was no other zone to work on, the driver would initiate
two packet_data objects for the same zone, causing unpredictable things to
happen.

Signed-off-by: Peter Osterlund <petero2@telia.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/block/pktcdvd.c |    4 +++-
 1 files changed, 3 insertions(+), 1 deletion(-)

diff -puN drivers/block/pktcdvd.c~cdrw-dvd-packet-writing-data-corruption-fix drivers/block/pktcdvd.c
--- 25/drivers/block/pktcdvd.c~cdrw-dvd-packet-writing-data-corruption-fix	2005-05-15 20:53:42.000000000 -0700
+++ 25-akpm/drivers/block/pktcdvd.c	2005-05-15 20:53:42.000000000 -0700
@@ -914,8 +914,10 @@ static int pkt_handle_queue(struct pktcd
 		bio = node->bio;
 		zone = ZONE(bio->bi_sector, pd);
 		list_for_each_entry(p, &pd->cdrw.pkt_active_list, list) {
-			if (p->sector == zone)
+			if (p->sector == zone) {
+				bio = NULL;
 				goto try_next_bio;
+			}
 		}
 		break;
 try_next_bio:
_
